==> mmoo_country_pickers-1.0.0.tar.gz: lib/utils/utils.dart <==
import 'package:mmoo_country_pickers/countries.dart';
import 'package:mmoo_country_pickers/country.dart';
import 'package:flutter/widgets.dart';

class CountryPickerUtils {
  static Country? getCountryByIso3Code(String? iso3Code) {
    try {
      if (iso3Code?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) =>
        country.iso3Code.toLowerCase() == iso3Code?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }

  static Country? getCountryByIsoCode(String? isoCode) {
    try {
      if (isoCode?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) => country.isoCode.toLowerCase() == isoCode?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }

  static Country? getCountryByName(String? name) {
    try {
      if (name?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) => country.name.toLowerCase() == name?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }

  static String getFlagImageAssetPath(String? isoCode) {
    if (isoCode?.isEmpty != false) {
      return "";
    }
    return "assets/${isoCode?.toLowerCase()}.png";
  }

  static Widget getDefaultFlagImage(Country country) {
    return Image.asset(
      CountryPickerUtils.getFlagImageAssetPath(country.isoCode),
      height: 20.0,
      width: 30.0,
      fit: BoxFit.fill,
      package: "country_pickers",
    );
  }

  static Country? getCountryByPhoneCode(String? phoneCode) {
    try {
      if (phoneCode?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) =>
        country.phoneCode.toLowerCase() == phoneCode?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }
}

==> mmoo_country_pickers-1.0.1.tar.gz: lib/utils/utils.dart <==
import 'package:mmoo_country_pickers/countries.dart';
import 'package:mmoo_country_pickers/country.dart';
import 'package:flutter/widgets.dart';

class CountryPickerUtils {
  static Country? getCountryByIso3Code(String? iso3Code) {
    try {
      if (iso3Code?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) =>
        country.iso3Code.toLowerCase() == iso3Code?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }

  static Country? getCountryByIsoCode(String? isoCode) {
    try {
      if (isoCode?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) => country.isoCode.toLowerCase() == isoCode?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }

  static Country? getCountryByName(String? name) {
    try {
      if (name?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) => country.name.toLowerCase() == name?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }

  static String getFlagImageAssetPath(String? isoCode) {
    if (isoCode?.isEmpty != false) {
      return "";
    }
    return "assets/${isoCode?.toLowerCase()}.png";
  }

  static Widget getDefaultFlagImage(Country country) {
    return Image.asset(
      CountryPickerUtils.getFlagImageAssetPath(country.isoCode),
      height: 20.0,
      width: 30.0,
      fit: BoxFit.fill,
      package: "mmoo_country_pickers",
    );
  }

  static Country? getCountryByPhoneCode(String? phoneCode) {
    try {
      if (phoneCode?.isEmpty != false) {
        return null;
      }
      return countryList.firstWhere(
            (country) =>
        country.phoneCode.toLowerCase() == phoneCode?.toLowerCase(),
      );
    } catch (error) {
      return null;
    }
  }
}
